# Scopinator

A library for controlling telescopes (initially Seestars).

## Versioning

This project uses [CalVer](https://calver.org/) versioning in a SemVer-compatible format:

**Format: `YYYY.MM.PATCH`**

- `YYYY`: Full year (e.g., 2025)
- `MM`: Month without zero-padding (e.g., 8 for August)
- `PATCH`: Patch version for bug fixes within the month (starts at 0)

This format is compatible with Semantic Versioning where:
- `YYYY` acts as the MAJOR version
- `MM` acts as the MINOR version
- `PATCH` acts as the PATCH version

Example: `2025.8.0` means the first release in August 2025.
